@@ -721,7 +721,7 @@ class UDM_Module(object):
             raise
         except udm_errors.base as exc:
             MODULE.info('Failed to retrieve LDAP object: %s' % (exc,))
-            if isinstance(exc, udm_errors.noObject) and superordinate and not ldap_connection.get(superordinate):
+            if isinstance(exc, udm_errors.noObject) and superordinate and not ldap_connection.get(superordinate.dn):
                 raise SuperordinateDoesNotExist(superordinate)
             UDM_Error(exc).reraise()
         return obj
@@ -1068,6 +1068,10 @@ class UDM_Module(object):
     def superordinate_names(self):
         return udm_modules.superordinate_names(self.module)
 
+    @property
+    def is_policy_multivalue(self):
+        return getattr(self.module, 'multivalue_policy', False)
+
     @property
     def policies(self):
         """
@@ -1084,7 +1088,7 @@ class UDM_Module(object):
         policies = []
         for policy in policyTypes:
             module = UDM_Module(policy, ldap_connection=ldap_connection, ldap_position=ldap_position)
-            policies.append({'objectType': policy, 'label': module.title, 'description': module.description})
+            policies.append({'objectType': policy, 'label': module.title, 'description': module.description, 'multivalue': module.is_policy_multivalue})
 
         return policies
 
